# EE-status-v3 #

## Summary ##
This is a python webapp for getting status history for your cameras.

## Settings File ##
There is file `settings.py` that is needed to run.  You can create your application and setup credentials at: [https://developerv3.eagleeyenetworks.com/page/my-application-html](my applications).  You can also reach out to api_support@een.com for help.
